@@ -3,12 +3,17 @@ package App::Nopaste::Service::Rafb;
 use strict;
 use warnings;
 use base 'App::Nopaste::Service';
-use WWW::Pastebin::RafbNet::Create;
+
+sub available {
+    eval "require WWW::Pastebin::RafbNet::Create; 1"
+}
 
 sub run {
     my $self = shift;
     my %args = @_;
 
+    require WWW::Pastebin::RafbNet::Create;
+
     my $paster = WWW::Pastebin::RafbNet::Create->new;
     my $ok = $paster->paste(
         $args{text},
